//
// Created by 徐秋实 on 2021/12/13.
//

#ifndef LIGHTNING_FAST_C_TESTS_ENCODERS_LABEL_ENCODER_TEST_H_
#define LIGHTNING_FAST_C_TESTS_ENCODERS_LABEL_ENCODER_TEST_H_
#include "interface/label_encoder.h"
class LabelEncoderTest {
 public:
  static void basic_test();

};
#endif //LIGHTNING_FAST_C_TESTS_ENCODERS_LABEL_ENCODER_TEST_H_
